# =====Lendo dados de um .csv=================
#  lendo todos os parmetros de arquivos csv externos,
# um para 'a', um para 'b' e um para 'c'.
#============================================

# Parmetros

set J;
set I;
set K dimen 2;

param c{i in J};
param a{i in I,j in J};
param b{i in I};

# Variveis
var x{j in J} >= 0;

# Lendo de um csv -----------------------------------------------------------------------
# Os arquivos .csv devem estar separados por virgula. Sempre  necessrio ter 
# uma coluna (ou mais) associada a um conjunto (set).
#
# M7_c: nome da tabela no csv
# O conjunto J  preenchido diretamente pela coluna 'Indice' no arquivo, e o parmetro c pela coluna Valor.
#
# Para escrever dados em mais de uma dimenso, como a matriz a,  necessrio criar as combinaes de indices
# por linhas, ou seja, deve haver uma coluna para cada indice e em seguida uma para o valor atribuido a esses indices.
# Deve existir um conjunto que receber todos os indices, o conjunto deve ter a mesma dimenso do nmero de indices.
# aqui no caso, 'a'  uma matrix 2x2, portanto criamos o conjunto K (set k dimen 2) para ele.
table M7_c IN "CSV" "M7_c.csv" : J <- [Indice], c ~ Valor;
table M7_b IN "CSV" "M7_b.csv" : I <- [Indice], b ~ Valor;
table M7_a IN "CSV" "M7_a.csv" : K <- [linha,coluna], a ~ Valor;
 # -----------------------------------------------------------------------

# Modelo
maximize cost: sum{j in J} c[j] * x[j];
s.t. r{i in I}: sum{j in J} a[i,j] * x[j] <= b[i];

solve;

# Impresso do resultado usando um lao for em um arquivo de 
# de .csv. Basta adicionar >> "nome_do_arquivo.csv". Quando rodar
# de novo, APAGAR o arquivo .csv, caso contrrio
printf "Variveis;Valores\n" >> "output.csv"; # Cabealho da tabela
for{j in J}
{
	printf "x" & j & ";"  & x[j] & "\n" >> "output.csv";
}
printf "Custo" & ";" & cost >> "output.csv";

end;

